Struct diem_sdk::crypto::_once_cell::race::OnceNonZeroUsize [−]
pub struct OnceNonZeroUsize { /* fields omitted */ }Expand description
A thread-safe cell which can be written to only once.
Implementations
impl OnceNonZeroUsize
impl OnceNonZeroUsize
pub const fn new() -> OnceNonZeroUsize
pub const fn new() -> OnceNonZeroUsize
Creates a new empty cell.
pub fn get(&self) -> Option<NonZeroUsize>
pub fn get(&self) -> Option<NonZeroUsize>
Gets the underlying value.
pub fn set(&self, value: NonZeroUsize) -> Result<(), ()>
pub fn set(&self, value: NonZeroUsize) -> Result<(), ()>
Sets the contents of this cell to value.
Returns Ok(()) if the cell was empty and Err(()) if it was
full.
pub fn get_or_init<F>(&self, f: F) -> NonZeroUsize where
F: FnOnce() -> NonZeroUsize,
pub fn get_or_init<F>(&self, f: F) -> NonZeroUsize where
F: FnOnce() -> NonZeroUsize,
Gets the contents of the cell, initializing it with f if the cell was
empty.
If several threads concurrently run get_or_init, more than one f can
be called. However, all threads will return the same value, produced by
some f.
pub fn get_or_try_init<F, E>(&self, f: F) -> Result<NonZeroUsize, E> where
F: FnOnce() -> Result<NonZeroUsize, E>,
pub fn get_or_try_init<F, E>(&self, f: F) -> Result<NonZeroUsize, E> where
F: FnOnce() -> Result<NonZeroUsize, E>,
Gets the contents of the cell, initializing it with f if
the cell was empty. If the cell was empty and f failed, an
error is returned.
If several threads concurrently run get_or_init, more than one f can
be called. However, all threads will return the same value, produced by
some f.